# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs


class FolderResponse(UniversalBaseModel):
    """
    Combined response with tree data and visualization.
    """

    structure_tree_ascii: str
    tree_data: typing.Dict[str, "AssetNode"]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .asset_node import AssetNode  # noqa: E402, F401, I001

update_forward_refs(FolderResponse)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import ToolsDataFrameRequestColumnsItem
from . import calendar, email, sheets, structured_data_extractor, tasks
from .sheets import InsertTableRowRequestRowDataItemValue

__all__ = [
    "InsertTableRowRequestRowDataItemValue",
    "ToolsDataFrameRequestColumnsItem",
    "calendar",
    "email",
    "sheets",
    "structured_data_extractor",
    "tasks",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .insert_table_row_request_row_data_item_value import InsertTableRowRequestRowDataItemValue

__all__ = ["InsertTableRowRequestRowDataItemValue"]
